# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Note: optional dependency Sub::Util is packaged with Scalar-List-Utils ≥ 1.40 (August 2014)

Name:		perl-Sub-Quote
Version:	2.006006
Release:	1.%{__distinit}%{__distvers}
Summary:	Efficient generation of subroutines via string eval
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/Sub-Quote
Source0:	https://cpan.metacpan.org/modules/by-module/Sub/Sub-Quote-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(B)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Optional Module Runtime
BuildRequires:	perl(Sub::Name)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(overload)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Test::Fatal) >= 0.003
BuildRequires:	perl(Test::More) >= 0.96
BuildRequires:	perl(threads)
BuildRequires:	perl(utf8)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Sub::Name)

# Package split from perl-Moo at 2.003000
Conflicts:	perl-Moo < 2.003000

%description
This package provides performant ways to generate subroutines from strings.

%prep
%setup -q -n Sub-Quote-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Sub/
%{_mandir}/man3/Sub::Defer.3*
%{_mandir}/man3/Sub::Quote.3*

%changelog
* Wed Oct  2 2019 Paul Howarth <paul@city-fan.org> - 2.006006-1
- Update to 2.006006
  - Change quotify of NaNs to simpler calculation
  - Avoid ever triggering exceptions when testing for quotify on false values
  - Skip quotify Inf and NaN tests if perl is compiled without support for them
  - Fix quotify of very large or very small numbers
  - Fix accuracy of quotify on high precision numbers when perl is compiled
    with quadmath
  - quotify will use hex floats when needed for full accuracy if they are
    available
  - Change tests of quotify for floating point numbers to allow a small amount
    of inaccuracy, since decimal floats can't always be accurate
  - Additional fixes for quotify for floating point numbers to be faster and
    should always be able to maintain accuracy
  - Change quotify to use longest form of floating point numbers if unable to
    find a perfectly accurate representation
  - Updated documentation for quotify to reflect handling of floating point
    numbers
  - Don't try to copy hints hash entries that look like references
    (CPAN RT#122698)

* Mon Mar 11 2019 Paul Howarth <paul@city-fan.org> - 2.006003-1
- Update to 2.006003
  - Don't test threads behaviour on perl < 5.8.5, since they are too unstable
  - More tests
  - Preserve inf, nan, and false in quotify
  - Improve accuracy of quotified floating point numbers
  - SUB_QUOTE_DEBUG can now be set to sub names, package names, or a regex to
    match against the code to filter which generated subs are printed to STDERR
  - Avoid warnings or failures on new perls when testing quoting UTF-8 strings
  - Test quotify output under utf8 pragma
  - Fix quoting of negative NaN
  - Fix quotifying of backslashes in utf8-flagged strings on perl 5.10.0
- Package LICENSE file
- Switch upstream from search.cpan.org to metacpan.org

* Fri Apr 20 2018 Paul Howarth <paul@city-fan.org> - 2.005001-1
- Update to 2.005001
  - Add a workaround for test failures on early 5.8 releases with threads

* Wed Feb  7 2018 Paul Howarth <paul@city-fan.org> - 2.005000-1
- Update to 2.005000
  - Fixed defer_info and undefer_sub from returning data for a deferred sub
    after it expires, even if the ref address matches
  - Fixed defer_info not returning info for undeferred unnamed subs after the
    deferred sub expires
  - Include options in defer_info return data
  - Exclude internals from defer_info return data
  - Document defer_info function
  - Encode all utf8 flagged scalars as strings, since they generally will
    always have originated as strings, which avoids future warning on bitwise
    ops on strings with wide characters
  - More thorough check for threads availability to avoid needless test failures
  - Added file and line options to quote_sub to allow specifying apparent source
    location
  - Documented additional options to Sub::Defer::defer_sub and
    Sub::Quote::quote_sub
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 18 2017 Paul Howarth <paul@city-fan.org> - 2.004000-1
- Update to 2.004000
  - More extensive quotify tests
  - Split tests into separate files
  - Propagate package to deferred subs, even if unnamed
  - Reject invalid attributes
  - Include line numbers compile errors (GH#1)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.96

* Mon Dec 12 2016 Paul Howarth <paul@city-fan.org> - 2.003001-1
- Initial RPM version
